@@ -16,10 +16,7 @@ class SnsLambdaSns(well_architected_stack.Stack):
     ) -> None:
         super().__init__(scope, id, **kwargs)
 
-        topic = aws_cdk.aws_sns.Topic(
-            self, 'SnsTopic',
-            display_name='SnsTopic'
-        )
+        topic = self.create_sns_topic('SnsTopic')
 
         self.create_lambda_function(
             construct_id='SnsSubscriber',
